Learn R Programming

dfcrm (version 0.1-3)

crm: Executing the CRM

Description

crm is used to compute a dose for the next patient in a phase I trial according to the CRM.

Usage

crm(prior, target, tox, level, n = length(level), dosename = NULL, 
    include = 1:n, pid = 1:n, conf.level = 0.9, method = "bayes", 
    model = "empiric", intcpt = 3, scale = sqrt(1.34), model.detail = TRUE, 
    patient.detail = TRUE, var.est = TRUE)

Arguments

prior
A vector of initial guesses of toxicity probabilities associated the doses.
target
The target DLT rate.
tox
A vector of patient outcomes; 1 indicates a toxicity, 0 otherwise.
level
A vector of dose levels assigned to patients. The length of level must be equal to that of tox.
n
The number of patients enrolled.
dosename
A vector containing the names of the regimens/doses used. The length of dosename must be equal to that of prior.
include
A subset of patients included in the dose calculation.
pid
Patient ID provided in the study. Its length must be equal to that of level.
conf.level
Confidence level for the probability/confidence interval of the returned dose-toxicity curve.
method
A character string to specify the method for parameter estimation. The default method "bayes" estimates the model parameter by the posterior mean. Maximum likelihood estimation is specified by "mle".
model
A character string to specify the working model used in the method. The default model is "empiric". A one-parameter logistic model is specified by "logistic".
intcpt
The intercept of the working logistic model. The default is 3. If model="empiric", this argument will be ignored.
scale
Standard deviation of the normal prior of the model parameter. Default is sqrt(1.34).
model.detail
If FALSE, the model content of an "mtd" object will not be displayed. Default is TRUE.
patient.detail
If FALSE, patient summary of an "mtd" object will not be displayed. Default is TRUE.
var.est
If TRUE, variance of the estimate of the model parameter and probability/confidence interval for the dose-toxicity curve will be computed

Value

  • An object of class "mtd" is returned, consisting of the summary of dose assignments thus far and the recommendation of dose for the next patient.
  • priorInitial guesses of toxicity rates.
  • targetThe target probability of toxicity at the MTD.
  • ptoxUpdated estimates of toxicity rates.
  • ptoxLLower confidence/probability limits of toxicity rates.
  • ptoxUUpper confidence/probability limits of toxicity rates.
  • mtdThe updated estimate of the MTD.
  • prior.varThe variance of the normal prior.
  • post.varThe posterior variance of the model parameter.
  • estimateEstimate of the model parameter.
  • methodThe method of estimation.
  • modelThe working model.
  • dosescaledThe scaled doses obtained via backward substitution.
  • toxPatients' toxicity indications.
  • levelDose levels assigned to patients.

Details

For maximum likelihood estimation, the variance of the estimate of $\beta$ (post.var) is approximated by the posterior variance of $\beta$ with a dispersed normal prior.

The empiric model is specified as $F(d, \beta) = d^{\exp(\beta)}$. The logistic model is specified as logit $(F(d,\beta))$ = intcpt $+ \exp(\beta) \times d$. For method="bayes", the prior on $\beta$ is normal with mean 0. Exponentiation of $\beta$ ensures an increasing dose-toxicity function.

References

O'Quigley, J. O., Pepe, M., and Fisher, L. (1990). Continual reassessment method: A practical design for phase I clinical trials in cancer. Biometrics 46:33-48.

Examples

Run this code
# Create a simple data set
prior <- c(0.05, 0.10, 0.20, 0.35, 0.50, 0.70)
target <- 0.2
level <- c(3, 4, 4, 3, 3, 4, 3, 2, 2, 2)
y <- c(0, 0, 1, 0, 0, 1, 1, 0, 0, 0)
foo <- crm(prior, target, y, level)
ptox <- foo$ptox  # updated estimates of toxicity rates

Run the code above in your browser using DataLab