Learn R Programming

dfcrm (version 0.1-2)

crmsens: Model Sensitivity in the CRM

Description

Evaluate the model sensitivity in the CRM by indifference intervals.

Usage

crmsens(prior, target, model = "empiric", intcpt = 3, eps = 1e-06, 
    maxit = 100, detail = FALSE)

Arguments

prior
A vector of initial guesses of toxicity probabilities associated the doses.
target
The target DLT rate.
model
A character string to specify the working model used in the method. The default model is ``empiric''. A one-parameter logistic model is specified by ``logistic''.
intcpt
The intercept of the working logistic model. The default is 3. If model=``empiric'', this argument will be ignored.
eps
Error tolerance in the computation of indifference intervals.
maxit
Maximum number of iterations in the computation of indifference intervals.
detail
If TRUE, the details of the ``H sets'' will be displayed. Default is FALSE.

Value

  • The function crmsens returns the model sensitivity for the model specifications given by the user.
  • HsetThe ``H sets'' of the model parameter.
  • iintThe indifference intervals of the dose-toxicity model associated with the test doses.

References

Cheung, Y. K. and Chappell, R. (2002). A simple technique to evaluate model sensitivity in the continual reassessment method. Biometrics 58:671-674.

See Also

crm, getprior

Examples

Run this code
prior <- c(0.05,0.10,0.20,0.35,0.50,0.70)
target <- 0.2
foo <- crmsens(prior,target,model="logistic",intcpt=2,detail=TRUE)

Run the code above in your browser using DataLab