Learn R Programming

dfcrm (version 0.1-2)

getprior: Calibrating prior DLT rates

Description

Returns a vector of initial guesses of toxicity probabilities associated the doses for a given model sensitivity (set of indifference intervals).

Usage

getprior(halfwidth, target, nu, nlevel, model = "empiric", intcpt = 3)

Arguments

halfwidth
The desired halfwidth of the indifference intervals.
target
The target DLT rate.
nu
The prior guess of MTD.
nlevel
The number of test doses.
model
A character string to specify the working model used in the method. The default model is ``empiric''. A one-parameter logistic model is specified by ``logistic''.
intcpt
The intercept of the working logistic model. The default is 3. If model=``empiric'', this argument will be ignored.

Value

  • A vector of length nlevel is returned.

Details

getprior is an ``inverse'' function of crmsens which gives the indifference intervals for a given set of initial guesses.

References

Cheung, Y. K. and Chappell, R. (2002). A simple technique to evaluate model sensitivity in the continual reassessment method. Biometrics 58:671-674.

See Also

crmsens

Examples

Run this code
target <- 0.25
delta <- 0.10
mtd0 <- 3

# initial DLT rates with indifference intervals [0.15, 0.35].
prior <- getprior(delta, target, mtd0,nlevel=6, model="logistic")

Run the code above in your browser using DataLab