Learn R Programming

dfcrm (version 0.1-2)

titecrm: Executing the TITE-CRM

Description

titecrm is used to compute a dose for the next patient in a phase I trial according to the TITE-CRM.

Usage

titecrm(prior, target, tox, level, n = length(level), weights = NULL,
followup = NULL, entry = NULL, exit = NULL, obswin = NULL, 
scheme = "linear", conf.level = 0.9, dosename = NULL, include = 1:n, 
pid = 1:n, method = "bayes", model = "empiric", var.est = TRUE, 
scale = sqrt(1.34), intcpt = 3, model.detail = TRUE, patient.detail = TRUE, 
tite = TRUE)

Arguments

prior
A vector of initial guesses of toxicity probabilities associated the doses.
target
The target DLT rate.
tox
A vector of patient outcomes; 1 indicates a toxicity, 0 otherwise.
level
A vector of dose levels assigned to patients. The length of level must be equal to that of tox.
n
The number of patients enrolled.
weights
A vector of weights assigned to observations. A weight must be between 0 and 1. If given, the arguments followup, entry, exit, obswin, and scheme will be ignored. If not su
followup
A vector of follow-up times of patients. If given, the arguments entry and exit will be ignored.
entry
A vector of entry times of the patients.
exit
A vector of exit times of the patients due to either end of follow-up or toxicity.
obswin
The observation window with respect to which the MTD is defined. If not supplied, users must provide weights.
scheme
A character string to specify the method for assigning weights. Default is ``linear''. An adaptive weight function is specified by ``adaptive''.
conf.level
Confidence level for the probability/confidence interval of the returned dose-toxicity curve.
dosename
A vector containing the names of the regimens/doses used. The length of dosename must be equal to that of prior.
include
A subset of patients included in the dose calculation.
pid
Patient ID provided in the study. Its length must be equal to that of level.
method
A character string to specify the method for parameter estimation. The default method ``bayes'' estimates the model parameter by the posterior mean. Maximum likelihood estimation is specified by ``mle''.
model
A character string to specify the working model used in the method. The default model is ``empiric''. A one-parameter logistic model is specified by ``logistic''.
var.est
If TRUE, variance of the estimate of the model parameter and probability/confidence interval for the dose-toxicity curve will be computed.
scale
Standard deviation of the normal prior of the model parameter. Default is sqrt(1.34).
intcpt
The intercept of the working logistic model. The default is 3. If model=``empiric'', this argument will be ignored.
model.detail
If FALSE, the model content of an ``mtd'' object will not be displayed. Default is TRUE.
patient.detail
If FALSE, patient summary of an ``mtd'' object will not be displayed. Default is TRUE.
tite
If FALSE, the time components in patient summary of an ``mtd'' object will be omitted. Default in TRUE.

Value

  • An object of class ``mtd'' is returned, consisting of the summary of dose assignments thus far and the recommendation of dose for the next patient.
  • priorInitial guesses of toxicity rates.
  • targetThe target probability of toxicity at the MTD.
  • ptoxUpdated estimates of toxicity rates.
  • ptoxLLower confidence/probability limits of toxicity rates.
  • ptoxUUpper confidence/probability limits of toxicity rates.
  • mtdThe updated estimate of the MTD.
  • prior.varThe variance of the normal prior.
  • post.varThe posterior variance of the model parameter.
  • estimateEstimate of the model parameter.
  • methodThe method of estimation.
  • modelThe working model.
  • dosescaledThe scaled doses obtained via backward substitution.
  • toxPatients' toxicity indications.
  • levelDose levels assigned to patients.
  • followupFollow-up times of patients.
  • obswinObservation window with respect to which the MTD is defined.
  • weightsWeights assigned to patients.
  • entryEntry times of patients.
  • exitExit times of patients.
  • schemeWeighting scheme.

Details

The adaptive weighting scheme is given in Cheung and Chappell (2000) given in the reference list.

References

Cheung, Y. K. and Chappell, R. (2000). Sequential designs for phase I clinical trials with late-onset toxicities. Biometrics 56:1177-1182.

See Also

crm

Examples

Run this code
# Create a simple data set
prior <- c(0.05,0.10,0.20,0.35,0.50,0.70)
target <- 0.2
level <- c(3,3,3,4,4,3,2,2,2,3)
y <- c(0,0,1,0,1,0,0,0,0,0)
u <- c(178,181,168,181,24,181,179, 102, 42, 3)
tau <- 180
foo <- titecrm(prior,target,y,level,followup=u,obswin=tau)
rec <- foo$mtd  # recommend a dose level for next patient

# An example with adaptive weight
foo2 <- titecrm(prior,target,y,level,followup=u,obswin=tau,scheme="adaptive")
wts <- foo2$weights

# The `weights' argument makes `followup' and `obswin' obsolete
foo3 <- titecrm(prior,target,y,level,weights=wts,followup=u,obswin=tau)
plot(foo3,ask=T)

# Patient time information via `entry' and `exit' arguments
entry <- c(7, 29, 49, 76, 92, 133, 241, 303, 363, 402) # entry time (days since study begins)
exit <- c(185,210,217,257,116,314,420,405,405,405) # exit time (days since study begins)
foo4 <- titecrm(prior,target,y,level,exit=exit,entry=entry,obswin=tau)
plot(foo4,ask=T)

Run the code above in your browser using DataLab