titesim is used to generate simulation replicates of phase I
trial using the TITE-CRM under a specified dose-toxicity
configuration.titesim(PI, prior, target, n, x0, nsim = 1, restrict = TRUE, obswin = 1,
tgrp = obswin, rate = 1, accrual = "fixed", surv = "uniform", scheme =
"linear", count = TRUE, method = "bayes", model = "empiric", intcpt = 3,
scale = sqrt(1.34), seed = 1009)PI.n.obswin, i.e., complete
follow-up in all current patients is required before escalation to
the next dose group. This argument is used only obswin]. Other survival distributions including exponential and
Weibull are to be made available.model=``empiric'', this argument will be
ignored.nsim=1, the time component of
individual subjects in the simulated trial is available via the
values arrival, toxicity.time, and
toxicity.study.time which respectively contain patients'
arrival times, times-to-toxicity, and the times-to-toxicity per study time.
For a ``sim'' object with nsim>1, the time component of the
design is summarized via the value Duration, which is the
duration of the simulated trials, computed by adding the arrival time
of the last patient and obswin.All ``sim'' objects contain at least the following components:
nsim=1, this
is a single numeric value of the recommended MTD of in simulated
trial.nsim=1, this is a vector of length n indicating the
doses assigned to the patients in the simulated trial.nsim=1, this is a vector of length n indicating the
toxicity outcomes of the patients in the simulated trial.Cheung, Y. K. (2005). Coherence principles in dose-finding studies. Biometrika 92:863-873.
crmsim, titecrm.PI <- c(0.10,0.20,0.40,0.50,0.60,0.65)
prior <- c(0.05,0.10,0.20,0.35,0.50,0.70)
target <- 0.2
x0 <- c(rep(1,3),rep(2,3),rep(3,3),rep(4,3),rep(5,3),rep(6,9))
# Generate a single replicate of two-stage TITE-CRM trial of size 24
foo <- titesim(PI,prior,target,24,x0, obswin=6,rate=4,accrual="poisson")
plot(foo,ask=T) # summarize trial graphically
# Generate 10 replicates of TITE-CRM trial of size 24
foo10 <- titesim(PI,prior,target,24,3,nsim=10,obswin=6,rate=4,accrual="poisson")
foo10Run the code above in your browser using DataLab