crm is used to compute a dose for the next patient in a phase I
trial according to the CRM.crm(prior, target, tox, level, n = length(level), dosename = NULL,
include = 1:n, pid = 1:n, conf.level = 0.9, method = "bayes",
model = "empiric", intcpt = 3, scale = sqrt(1.34), model.detail = TRUE,
patient.detail = TRUE, var.est = TRUE)level must be equal to that of tox.dosename must be equal to that of
prior.level."bayes" estimates the model
parameter by the posterior mean. Maximum likelihood estimation
is specified by "mle"."empiric". A one-parameter
logistic model is specified by "logistic".model="empiric", this argument will be
ignored."mtd" object
will not be displayed. Default is TRUE."mtd" object
will not be displayed. Default is TRUE."mtd" is returned, consisting of the summary
of dose assignments thus far and the recommendation of dose for the
next patient.post.var) is approximated by the posterior variance of
$\beta$ with a dispersed normal prior. The empiric model is specified as $F(d, \beta) = d^{\exp(\beta)}$.
The logistic model is specified as logit $(F(d,\beta))$ = intcpt
$+ \exp(\beta) \times d$. For method="bayes", the prior on
$\beta$ is normal with mean 0. Exponentiation of $\beta$ ensures an
increasing dose-toxicity function.
# Create a simple data set
prior <- c(0.05, 0.10, 0.20, 0.35, 0.50, 0.70)
target <- 0.2
level <- c(3, 4, 4, 3, 3, 4, 3, 2, 2, 2)
y <- c(0, 0, 1, 0, 0, 1, 1, 0, 0, 0)
foo <- crm(prior, target, y, level)
ptox <- foo$ptox # updated estimates of toxicity ratesRun the code above in your browser using DataLab